@@ -1,5 +1,8 @@
 package Monkey::Patch::Action::Handle;
 
+our $DATE = '2018-04-02'; # DATE
+our $VERSION = '0.060'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
@@ -7,8 +10,6 @@ use warnings;
 use Scalar::Util qw(weaken);
 use Sub::Delete;
 
-our $VERSION = '0.03'; # VERSION
-
 my %stacks;
 
 sub __find_previous {
@@ -64,7 +65,6 @@ sub new {
             goto &{$self->{code}};
         };
         push @$stack, [$type => $code => $wrapper];
-        no warnings; # shut up warning about prototype mismatch
         *$name = $wrapper;
     }
 
@@ -97,7 +97,6 @@ sub DESTROY {
                     if ($stack->[$i-1][0] eq 'delete') {
                         delete_sub $name;
                     } else {
-                        no warnings; # shut up warning about prototype mismatch
                         *$name = $stack->[$i-1][2] // $stack->[$i-1][1];
                     }
                 } else {
@@ -112,30 +111,47 @@ sub DESTROY {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Monkey::Patch::Action::Handle
 
 =head1 VERSION
 
-version 0.03
+This document describes version 0.060 of Monkey::Patch::Action::Handle (from Perl distribution Monkey-Patch-Action), released on 2018-04-02.
 
 =for Pod::Coverage .*
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Monkey-Patch-Action>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Monkey-Patch-Action>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Monkey-Patch-Action>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2018, 2017, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
